@@ -4,7 +4,6 @@ import click
 
 URL_TEMPLATE = "\e]8;;{url}\a{title}\e]8;;\a"
 
-
 def info(msg):
     click.echo(click.wrap_text(msg))
 
@@ -18,6 +17,5 @@ def paragraph(msg):
 
 
 def link(url, title):
-    os.system(
-        f"""echo -e '{URL_TEMPLATE.format(url=url, title=click.wrap_text(title))}'"""
-    )
+    string = URL_TEMPLATE.format(url=url, title=click.wrap_text(title))
+    os.system(f'echo -e """{string}"""')
